@@ -8,7 +8,8 @@ from twisted.internet.ssl import PrivateCertificate
 
 
 def _makeCertificate(key, email, _utcnow=datetime.utcnow):
-    """Make the certificate for the given key and e-mail address.
+    """Make the certificate for the client using the given key and e-mail
+    address.
 
     """
     # Create a certificate for this key.
@@ -47,21 +48,25 @@ def _generateKey(_PKey=PKey):
 
 
 def makeCredentials(path, email):
-    """Make credentials from given e-mail address and store them in the
-    directory at path.
+    """Make credentials for the client from given e-mail address and store
+    them in the directory at path.
 
     """
     key = _generateKey()
     cert = _makeCertificate(key, email)
 
-    with path.child("client.pem").open("wb") as pemFile:
+    certPath = path.child("client.pem")
+    certPath.alwaysCreate = True
+
+    with certPath.open("wb") as pemFile:
         pemFile.write(dump_privatekey(FILETYPE_PEM, key))
         pemFile.write(dump_certificate(FILETYPE_PEM, cert))
 
 
 
 def getContextFactory(path):
-    """Get a context factory from keys already stored at path.
+    """Get a context factory for the client from keys already stored at
+    path.
 
     """
     with path.child("client.pem").open() as pemFile:
@@ -74,7 +79,8 @@ def getContextFactory(path):
 
 
 class SecureCiphersContextFactory(object):
-    """A context factory to limit SSL/TLS connections to secure ciphersuites.
+    """A context factory to limit SSL/TLS connections to secure
+    ciphersuites.
 
     This wraps another context factory. When asked for a context, it
     asks the wrapped context factory for one, and then limits the
